# cutest

[![Build Status](https://travis-ci.com/jessebrennan/cutest.svg?branch=master)](https://travis-ci.com/jessebrennan/cutest)

A cute, composable unit test framework for Python

## Documentation

TODO :) but for an example took in `test/sample`.

## Release instructions

1. On a clean, up-to-date, version of `master`, run:
   ```
   make release version=VERSION
   ```
   where `VERSION` is one of `{major, minor, patch, X.X.X}`.

2. Commit with a message like `Update version`.

3. Push to `master` (😱).

4. Make a release through the Github UI.
